'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

exports.default = function (_ref) {
  var t = _ref.types;

  var dataPrefix = 'data-qa';
  var classPrefix = 'className';
  var jssClassPrefix = 'classes';

  var fileNameAttr = void 0;
  var nodeNameAttr = void 0;

  var visitor = {
    Program: function Program(path, state) {
      if (state.opts.dataPrefix) {
        dataPrefix = state.opts.prefix;
      }

      if (state.opts.classPrefix) {
        classPrefix = state.opts.classPrefix;
      }

      if (state.opts.jssClassPrefix) {
        jssClassPrefix = state.opts.jssClassPrefix;
      }

      fileNameAttr = dataPrefix + '-file';
      nodeNameAttr = dataPrefix + '-class';
    },
    JSXOpeningElement: function JSXOpeningElement(path, state) {
      var attributes = path.node.attributes;
      var newAttributes = [];

      var classNode = attributes.find(function (attr) {
        return attr.name && attr.name.name === classPrefix;
      });

      if (classNode) {
        var classExpr = classNode.value.expression;

        if (classExpr) {
          var attrValue = '';

          if (classExpr.object && classExpr.object.name === jssClassPrefix) {
            attrValue = classExpr.property.name || classExpr.property.value;
          } else if (classExpr.arguments) {
            var values = classExpr.arguments.map(_transpile);
            attrValue = values.join(' ');
          }

          newAttributes.push(t.jSXAttribute(t.jSXIdentifier(nodeNameAttr), t.stringLiteral(attrValue)));
        }
      }

      if (state.file && state.file.opts && state.file.opts.basename) {
        newAttributes.push(t.jSXAttribute(t.jSXIdentifier(fileNameAttr), t.stringLiteral(state.file.opts.basename)));
      }

      attributes.push.apply(attributes, newAttributes);
    }
  };

  return { visitor: visitor };

  function _transpile(data) {
    if (t.isObjectExpression(data)) {
      return _transpileObject(data);
    } else if (t.isMemberExpression(data) && data.object.name === jssClassPrefix) {
      return data.property.name;
    } else if (t.isArrayExpression(data)) {
      return _transpileArray(data);
    }
  }

  function _transpileObject(obj) {
    var values = obj.properties.map(function (prop) {
      if (t.isMemberExpression(prop.key) && prop.key.object.name === jssClassPrefix) {
        return prop.key.property.name;
      } else {
        return prop.key.name;
      }
    });

    return values.join(' ');
  }

  function _transpileArray(arr) {
    var values = arr.elements.map(function (el) {
      if (t.isMemberExpression(el) && el.object.name === jssClassPrefix) {
        return el.property.name;
      } else {
        return el.value;
      }
    });

    return values.join(' ');
  }
};